@@ -7,13 +7,13 @@ OpenSRS::Country - ISO codes for country identification (ISO 3166)
 =head1 SYNOPSIS
 
     use OpenSRS::Country;
-    
+
     $country = code2country('jp');               # $country gets 'Japan'
     $code    = country2code('Norway');           # $code gets 'no'
-    
+
     @codes   = all_country_codes();
     @names   = all_country_names();
-    
+
     # add "uk" as a pseudo country code for United Kingdom
     OpenSRS::Country::_alias_code('uk' => 'gb');
 
@@ -82,7 +82,7 @@ use OpenSRS::Constants;
 #	Public Global Variables
 #-----------------------------------------------------------------------
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-$VERSION   = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
+$VERSION   = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
 @ISA       = qw(Exporter);
 @EXPORT    = qw(code2country country2code
                 all_country_codes all_country_names
@@ -285,7 +285,7 @@ an ISO standard. If you would like 'uk' to work as the two-letter
 code for United Kingdom, use the following:
 
     use OpenSRS::Country;
-    
+
     OpenSRS::Country::_alias_code('uk' => 'gb');
 
 With this code, both "uk" and "gb" are valid codes for United Kingdom,
@@ -325,7 +325,7 @@ The user is prompted for a country code, and then told the corresponding
 country name:
 
     $| = 1;   # turn off buffering
-    
+
     print "Enter country code: ";
     chop($code = <STDIN>);
     $country = code2country($code, LOCALE_CODE_ALPHA_2);
@@ -508,7 +508,6 @@ cm:cmr:120:Cameroon
 cn:chn:156:China
 co:col:170:Colombia
 cr:cri:188:Costa Rica
-cs:cgs:189:Serbia and Montenegro
 cu:cub:192:Cuba
 cv:cpv:132:Cape Verde
 cx:::Christmas Island
@@ -562,6 +561,7 @@ id:idn:360:Indonesia
 ie:irl:372:Ireland
 il:isr:376:Israel
 in:ind:356:India
+im:imn:833:Isle of Man
 io:::British Indian Ocean Territory
 iq:irq:368:Iraq
 ir:irn:364:Iran, Islamic Republic of
@@ -604,6 +604,7 @@ mo:mac:446:Macau
 mp:mnp:580:Northern Mariana Islands
 mq:mtq:474:Martinique
 mr:mrt:478:Mauritania
+me:mne:499:Montenegro
 ms:msr:500:Montserrat
 mt:mlt:470:Malta
 mu:mus:480:Mauritius
@@ -657,6 +658,7 @@ sk:svk:703:Slovakia
 sl:sle:694:Sierra Leone
 sm:smr:674:San Marino
 sn:sen:686:Senegal
+rs:srb:688:Serbia
 so:som:706:Somalia
 sr:sur:740:Suriname
 st:stp:678:Sao Tome and Principe
