@@ -50,7 +50,7 @@ require Exporter;
 #	Public Global Variables
 #-----------------------------------------------------------------------
 use vars qw($VERSION @ISA @EXPORT_OK $OPENSRS);
-$VERSION      = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
+$VERSION      = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
 @ISA          = qw(Exporter);
 @EXPORT_OK       = qw(code2language language2code
                    all_language_codes all_language_names 
@@ -257,16 +257,27 @@ dan
 lit
 lav
 ice
-num
+hun
+spa
 kor
 swe
 pol
 /);
-    } elsif ( $fqdn =~ /\.info/ ){
+    } elsif ( $fqdn =~ /\.info$/ ){
 	return (sort qw/ 
 ger
+dan
+lit
+lav
+ice
+hun
+kor
+pol
+swe
 /);
-    } elsif ( $fqdn =~ /\.de/ ){
+    # No IDNs for .ASIA yet...
+    # } elsif ( $fqdn =~ /\.asia$/ ){
+    } elsif ( $fqdn =~ /\.de$/ ){
 	return (sort qw/ 
 alb
 cat
@@ -292,6 +303,17 @@ swe
 tur
 vie
 wel
+/);
+    } elsif ( $fqdn =~ /\.biz$/ ){
+	return (sort qw/ 
+chi
+dan
+ger
+ice
+jpn
+nor
+spa
+swe
 /);
     }
 }
