@@ -387,7 +387,7 @@ sub build_country_list {
 sub locale_build_country_list {
     my $default_id = shift;
 
-    $default_id ||= 'US';
+    $default_id = 'US' if not defined $default_id;
     $default_id =~ tr/a-z/A-Z/;
     my $html = join ("\n",map {
 	"<option value=" . 
