@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: XML_Client.pm,v 1.110 2006/03/21 00:04:24 sbelikov Exp $
+# $Id: XML_Client.pm,v 1.113 2008/03/12 17:07:47 sbelikov Exp $
 #       .Copyright (C)  2000 TUCOWS.com Inc.
 #       .Created:       11/19/1999
 #       .Contactid:     <admin@vpop.net>
@@ -406,7 +406,7 @@ sub validate {
 	if ($syntaxError = check_domain_syntax($domain)) {
 	    $problem_fields{Domain} = $domain . " - " . $syntaxError;
 	}
-        
+
         if ( $domain =~ /\.us$/ ) {
             if ( !$data->{app_purpose} ) {
                 push @missing_fields, "Domain Name Application Purpose";
@@ -508,7 +508,15 @@ sub validate_contacts {
 					tech => $default_contact,
 				    },
 				    eu => {
-				        owner => $default_contact,	
+				        owner => { 
+					    first_name => "First Name",
+					    last_name => "Last Name",
+					    address1 => "Address1",
+					    city => "City",
+					    country => "Country",
+					    phone => "Phone",
+					    email => "E-Mail"
+					}, 
 					tech => $default_contact,
 				    },
 				    be => {
@@ -603,10 +611,6 @@ sub validate_contacts {
     ####################################
     # check the required fields
     foreach $type (keys %contact_types) {
-	if($data->{reg_type} eq "transfer" and $data->{domain} =~ /\.de/ and $type eq 'owner') {
-	    #skip owner for .de transfers
-	    next;
-	}
 	if( !$data->{change_contact} and 
 	    $data->{reg_type} eq "transfer" and 
 	    $data->{domain} =~ /\.uk/ ){
@@ -648,7 +652,7 @@ sub validate_contacts {
 	    $problem_fields{"$contact_types{$type} Email"} = $data->{"${type}_email"};
 	}
         
-	if ( $data->{domain} =~ /\.(info|biz|name|us|de)/ ) {
+	if ( $data->{domain} =~ /\.(info|biz|name|us|de|asia)/ ) {
 	    if ($data->{"${type}_phone"} !~ /^\+\d{1,3}\.\d{1,12}( *x\d{1,4})?$/){
 		# tell the registrant about the bad phone number
 		$problem_fields{"$contact_types{$type} Phone"} =
